=======
Credits
=======

Development Lead
----------------

* Benjamin Parciany
* Mathieu Servillat

Contributors
------------

* Jean-François Sornay
* Michèle Sanguillon
* Mireille Louys
* François Bonnarel
* Catherine Boisson